@@ -14,15 +14,36 @@ readonly BRIGHT_VARIANTS=("" "light" "dark")
 if command -v lsb_release &> /dev/null; then
   Distributor_ID=$(lsb_release -i)
   if [[ "${Distributor_ID}" == "Distributor ID:	elementary" || "${Distributor_ID}" == "Distributor ID:	Elementary" ]]; then
-    ICON_VERION="elementary"
+    ICON_VERSION="elementary"
   else
-    ICON_VERION="normal"
+    ICON_VERSION="normal"
   fi
-  echo -e "Install $ICON_VERION version! ..."
+  # echo -e "Install $ICON_VERSION version! ..."
 else
-  ICON_VERION="normal"
+  ICON_VERSION="normal"
 fi
 
+export c_default="\033[0m"
+export c_blue="\033[1;34m"
+export c_magenta="\033[1;35m"
+export c_cyan="\033[1;36m"
+export c_green="\033[1;32m"
+export c_red="\033[1;31m"
+export c_yellow="\033[1;33m"
+
+prompt() {
+  case "${1}" in
+    "-s")
+      echo -e "  ${c_green}${2}${c_default}" ;;    # print success message
+    "-e")
+      echo -e "  ${c_red}${2}${c_default}" ;;      # print error message
+    "-w")
+      echo -e "  ${c_yellow}${2}${c_default}" ;;   # print warning message
+    "-i")
+      echo -e "  ${c_cyan}${2}${c_default}" ;;     # print info message
+  esac
+}
+
 usage() {
 cat << EOF
 Usage: $0 [OPTION] | [COLOR VARIANTS]...
@@ -32,6 +53,7 @@ OPTIONS:
   -c                       Install plasma colorscheme folder version
   -d DIR                   Specify theme destination directory (Default: $HOME/.local/share/icons)
   -n NAME                  Specify theme name (Default: Tela)
+  -r, -u                   Remove/uninstall icon themes (Default: all)
   -h                       Show this help
 
 COLOR VARIANTS:
@@ -130,10 +152,10 @@ install_theme() {
   local -r THEME_DIR="${DEST_DIR}/${THEME_NAME}"
 
   if [[ -d "${THEME_DIR}" ]]; then
-    rm -r "${THEME_DIR}"
+    rm -rf "${THEME_DIR}"
   fi
 
-  echo "Installing '${THEME_NAME}'..."
+  prompt -i "Installing '${THEME_NAME}'..."
 
   install -d "${THEME_DIR}"
 
@@ -169,7 +191,7 @@ install_theme() {
 
     cp -r "${SRC_DIR}"/links/{16,22,24,32,scalable,symbolic}                     "${THEME_DIR}"
 
-    if [[ "${ICON_VERION}" == 'elementary' || "$DESKTOP_SESSION" == 'xfce' ]]; then
+    if [[ "${ICON_VERSION}" == 'elementary' || "$DESKTOP_SESSION" == 'xfce' ]]; then
       cp -r "${SRC_DIR}/elementary/"*                                            "${THEME_DIR}"
     fi
   fi
@@ -196,13 +218,12 @@ install_theme() {
     ln -sr "${STD_THEME_DIR}/16/actions"                                         "${THEME_DIR}/16/actions"
     ln -sr "${STD_THEME_DIR}/16/apps"                                            "${THEME_DIR}/16/apps"
     ln -sr "${STD_THEME_DIR}/16/devices"                                         "${THEME_DIR}/16/devices"
-    ln -sr "${STD_THEME_DIR}/16/mimetypes"                                       "${THEME_DIR}/16/mimetypes"
     ln -sr "${STD_THEME_DIR}/16/places"                                          "${THEME_DIR}/16/places"
     ln -sr "${STD_THEME_DIR}/16/status"                                          "${THEME_DIR}/16/status"
     ln -sr "${STD_THEME_DIR}/22/actions"                                         "${THEME_DIR}/22/actions"
+    ln -sr "${STD_THEME_DIR}/22/categories"                                      "${THEME_DIR}/22/categories"
     ln -sr "${STD_THEME_DIR}/22/devices"                                         "${THEME_DIR}/22/devices"
     ln -sr "${STD_THEME_DIR}/22/emblems"                                         "${THEME_DIR}/22/emblems"
-    ln -sr "${STD_THEME_DIR}/22/mimetypes"                                       "${THEME_DIR}/22/mimetypes"
     ln -sr "${STD_THEME_DIR}/22/places"                                          "${THEME_DIR}/22/places"
     ln -sr "${STD_THEME_DIR}/24/actions"                                         "${THEME_DIR}/24/actions"
     ln -sr "${STD_THEME_DIR}/24/animations"                                      "${THEME_DIR}/24/animations"
@@ -224,7 +245,7 @@ install_theme() {
     # Change icon color for dark theme
     sed -i "s/#565656/#aaaaaa/g" "${THEME_DIR}"/{16,22,24}/actions/*.svg
     sed -i "s/#727272/#aaaaaa/g" "${THEME_DIR}"/{16,22,24}/{places,devices}/*.svg
-    sed -i "s/#555555/#aaaaaa/g" "${THEME_DIR}"/symbolic/{actions,apps,categories,devices,emblems,emotes,mimetypes,places,status}/*.svg
+    sed -i "s/#565656/#aaaaaa/g" "${THEME_DIR}"/symbolic/{actions,apps,categories,devices,emblems,emotes,mimetypes,places,status}/*.svg
 
     if [[ "$1" != "standard" ]]; then
       sed -i "s/#5294e2/${theme_color}/g" "${THEME_DIR}/16/places/"folder*.svg
@@ -244,11 +265,10 @@ install_theme() {
     ln -sr "${STD_THEME_DIR}/scalable"                                           "${THEME_DIR}/scalable"
     ln -sr "${STD_THEME_DIR}/32"                                                 "${THEME_DIR}/32"
     ln -sr "${STD_THEME_DIR}/16/apps"                                            "${THEME_DIR}/16/apps"
-    ln -sr "${STD_THEME_DIR}/16/mimetypes"                                       "${THEME_DIR}/16/mimetypes"
     ln -sr "${STD_THEME_DIR}/16/panel"                                           "${THEME_DIR}/16/panel"
     ln -sr "${STD_THEME_DIR}/16/status"                                          "${THEME_DIR}/16/status"
+    ln -sr "${STD_THEME_DIR}/22/categories"                                      "${THEME_DIR}/22/categories"
     ln -sr "${STD_THEME_DIR}/22/emblems"                                         "${THEME_DIR}/22/emblems"
-    ln -sr "${STD_THEME_DIR}/22/mimetypes"                                       "${THEME_DIR}/22/mimetypes"
     ln -sr "${STD_THEME_DIR}/22/panel"                                           "${THEME_DIR}/22/panel"
     ln -sr "${STD_THEME_DIR}/24/animations"                                      "${THEME_DIR}/24/animations"
     ln -sr "${STD_THEME_DIR}/24/panel"                                           "${THEME_DIR}/24/panel"
@@ -263,19 +283,37 @@ install_theme() {
   gtk-update-icon-cache "${THEME_DIR}"
 }
 
+uninstall_theme() {
+  # Appends a dash if the variables are not empty
+  if [[ "$1" != "standard" ]]; then
+    local -r colorprefix="-$1"
+  fi
+
+  local -r brightprefix="${2:+-$2}"
+
+  local -r THEME_NAME="${NAME}${colorprefix}${brightprefix}"
+  local -r THEME_DIR="${DEST_DIR}/${THEME_NAME}"
+
+  if [[ -d "${THEME_DIR}" ]]; then
+    rm -rf "${THEME_DIR}"
+    prompt -i "Uninstalling '${THEME_DIR}'..."
+  fi
+}
+
 while [ $# -gt 0 ]; do
   if [[ "$1" = "-a" ]]; then
     colors=("${COLOR_VARIANTS[@]}")
   elif [[ "$1" = "-c" ]]; then
     colorscheme="true"
-    echo "Folder color will follow the colorscheme on KDE plasma ..."
-    shift
+    prompt -s "Folder color will follow the colorscheme on KDE plasma ..."
   elif [[ "$1" = "-d" ]]; then
     DEST_DIR="$2"
     shift
   elif [[ "$1" = "-n" ]]; then
     NAME="$2"
     shift
+  elif [[ "$1" = "-u" || "$1" = "-r" ]]; then
+    uninstall="true"
   elif [[ "$1" = "-h" ]]; then
     usage
     exit 0
@@ -284,8 +322,8 @@ while [ $# -gt 0 ]; do
        [[ "${colors[*]}" != *$1* ]]; then
     colors+=("$1")
   else
-    echo "ERROR: Unrecognized installation option '$1'."
-    echo "Try '$0 -h' for more information."
+    prompt -e "ERROR: Unrecognized installation option '$1'."
+    prompt -w "Try '$0 -h' for more information."
     exit 1
   fi
 
@@ -295,9 +333,17 @@ done
 # Default name is 'Tela'
 : "${NAME:=Tela}"
 
-# By default, only the standard color variant is selected
-for color in "${colors[@]:-standard}"; do
-  for bright in "${BRIGHT_VARIANTS[@]}"; do
-    install_theme "${color}" "${bright}"
+if [[ ${uninstall} == 'true' ]]; then
+  for color in "${COLOR_VARIANTS[@]}"; do
+    for bright in "${BRIGHT_VARIANTS[@]}"; do
+      uninstall_theme "${color}" "${bright}"
+    done
   done
-done
+else
+  # By default, only the standard color variant is selected
+  for color in "${colors[@]:-standard}"; do
+    for bright in "${BRIGHT_VARIANTS[@]}"; do
+      install_theme "${color}" "${bright}"
+    done
+  done
+fi
